Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'target_explorer/plugins/org.eclipse.tcf.te.runtime.services/src')
-rw-r--r--target_explorer/plugins/org.eclipse.tcf.te.runtime.services/src/org/eclipse/tcf/te/runtime/services/interfaces/ISimulatorService.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/target_explorer/plugins/org.eclipse.tcf.te.runtime.services/src/org/eclipse/tcf/te/runtime/services/interfaces/ISimulatorService.java b/target_explorer/plugins/org.eclipse.tcf.te.runtime.services/src/org/eclipse/tcf/te/runtime/services/interfaces/ISimulatorService.java
index 3054083b3..4023183ff 100644
--- a/target_explorer/plugins/org.eclipse.tcf.te.runtime.services/src/org/eclipse/tcf/te/runtime/services/interfaces/ISimulatorService.java
+++ b/target_explorer/plugins/org.eclipse.tcf.te.runtime.services/src/org/eclipse/tcf/te/runtime/services/interfaces/ISimulatorService.java
@@ -26,21 +26,21 @@ public interface ISimulatorService extends IService {
* Starts the simulator.
*
* @param context The context. Must not be <code>null</code>.
* @param settings The encoded simulator settings or <code>null</code>.
* @param callback The callback to invoke once the operation finishes. Must not be <code>null</code>.
* @param monitor The progress monitor or <code>null</code>.
*/
- public void start(Object context, String settings, ICallback callback, IProgressMonitor monitor);
+ public void start(Object context, String config, ICallback callback, IProgressMonitor monitor);
/**
* Stops the simulator.
*
* @param context The context. Must not be <code>null</code>.
* @param settings The encoded simulator settings or <code>null</code>.
* @param callback The callback to invoke once the operation finishes. Must not be <code>null</code>.
* @param monitor The progress monitor or <code>null</code>.
*/
- public void stop(Object context, String settings, ICallback callback, IProgressMonitor monitor);
+ public void stop(Object context, String config, ICallback callback, IProgressMonitor monitor);
/**
* Checks if the simulator is running.
@@ -48,8 +48,8 @@ public interface ISimulatorService extends IService {
* The result of the check is return as {@link Boolean} object by the callback's {@link ICallback#getResult()} method.
*
* @param context The context. Must not be <code>null</code>.
* @param settings The encoded simulator settings or <code>null</code>.
* @param callback The callback to invoke once the operation finishes. Must not be <code>null</code>.
*/
- public void isRunning(Object context, String settings, ICallback callback);
+ public void isRunning(Object context, String config, ICallback callback);
}

Back to the top
@@ -26,21 +26,21 @@ public interface ISimulatorService extends IService {
*
* @param context The context. Must not be <code>null</code>.
- * @param settings The encoded simulator settings or <code>null</code>.
+ * @param config The encoded simulator settings or <code>null</code>.
* @param callback The callback to invoke once the operation finishes. Must not be <code>null</code>.
* @param monitor The progress monitor or <code>null</code>.
@@ -26,21 +26,21 @@ public interface ISimulatorService extends IService {
*
* @param context The context. Must not be <code>null</code>.
- * @param settings The encoded simulator settings or <code>null</code>.
+ * @param config The encoded simulator settings or <code>null</code>.
* @param callback The callback to invoke once the operation finishes. Must not be <code>null</code>.
* @param monitor The progress monitor or <code>null</code>.
@@ -48,8 +48,8 @@ public interface ISimulatorService extends IService {
*
* @param context The context. Must not be <code>null</code>.
- * @param settings The encoded simulator settings or <code>null</code>.
+ * @param config The encoded simulator settings or <code>null</code>.
* @param callback The callback to invoke once the operation finishes. Must not be <code>null</code>.
*/